@@ -39,7 +39,7 @@ class Server(EnvironmentMixin):
 
       - :attr:`Session.windows` [:class:`Window`, ...]
 
-        - :attr:`Window._panes` [:class:`Pane`, ...]
+        - :attr:`Window.panes` [:class:`Pane`, ...]
 
           - :class:`Pane`
 
@@ -500,8 +500,8 @@ class Server(EnvironmentMixin):
         """Windows belonging server.
 
         Can be accessed via
-        :meth:`.sessions.get() <libtmux._internal.query_list.QueryList.get()>` and
-        :meth:`.sessions.filter() <libtmux._internal.query_list.QueryList.filter()>`
+        :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
+        :meth:`.windows.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
         windows: t.List["Window"] = []
         for obj in fetch_objs(
@@ -518,8 +518,8 @@ class Server(EnvironmentMixin):
         """Panes belonging server.
 
         Can be accessed via
-        :meth:`.sessions.get() <libtmux._internal.query_list.QueryList.get()>` and
-        :meth:`.sessions.filter() <libtmux._internal.query_list.QueryList.filter()>`
+        :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
+        :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
         panes: t.List["Pane"] = []
         for obj in fetch_objs(
@@ -630,5 +630,11 @@ class Server(EnvironmentMixin):
         warnings.warn("Server.list_sessions is deprecated")
         return self.sessions
 
-    #: Alias :attr:`sessions` for :class:`~libtmux.common.TmuxRelationalObject`
-    children = sessions
+    @property
+    def children(self) -> QueryList["Session"]:  # type:ignore
+        """Was used by TmuxRelationalObject (but that's longer used in this class)
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server.children is deprecated")
+        return self.sessions
