@@ -1,11 +1,12 @@
 """Test for libtmux Session object."""
 import logging
+import shutil
 import typing as t
 
 import pytest
 
 from libtmux import exc
-from libtmux.common import has_gte_version
+from libtmux.common import has_gte_version, has_lt_version
 from libtmux.pane import Pane
 from libtmux.server import Server
 from libtmux.session import Session
@@ -17,7 +18,7 @@ logger = logging.getLogger(__name__)
 
 def test_has_session(server: Server, session: Session) -> None:
     """Server.has_session returns True if has session_name exists."""
-    TEST_SESSION_NAME = session.get("session_name")
+    TEST_SESSION_NAME = session.session_name
     assert TEST_SESSION_NAME is not None
     assert server.has_session(TEST_SESSION_NAME)
     if has_gte_version("2.1"):
@@ -30,16 +31,16 @@ def test_select_window(session: Session) -> None:
     """Session.select_window moves window."""
     # get the current window_base_index, since different user tmux config
     # may start at 0 or 1, or whatever they want.
-    window_idx = session.attached_window.get("window_index")
+    window_idx = session.attached_window.window_index
     assert window_idx is not None
     window_base_index = int(window_idx)
 
     session.new_window(window_name="test_window")
-    window_count = len(session._windows)
+    window_count = len(session.windows)
 
     assert window_count >= 2  # 2 or more windows
 
-    assert len(session._windows) == window_count
+    assert len(session.windows) == window_count
 
     # tmux selects a window, moves to it, shows it as attached_window
     selected_window1 = session.select_window(window_base_index)
@@ -66,10 +67,10 @@ def test_select_window(session: Session) -> None:
 def test_select_window_returns_Window(session: Session) -> None:
     """Session.select_window returns Window object."""
 
-    window_count = len(session._windows)
-    assert len(session._windows) == window_count
+    window_count = len(session.windows)
+    assert len(session.windows) == window_count
 
-    window_idx = session.attached_window.get("window_index")
+    window_idx = session.attached_window.window_index
     assert window_idx is not None
     window_base_index = int(window_idx)
     window = session.select_window(window_base_index)
@@ -88,17 +89,17 @@ def test_attached_pane(session: Session) -> None:
 
 def test_session_rename(session: Session) -> None:
     """Session.rename_session renames session."""
-    session_name = session.get("session_name")
+    session_name = session.session_name
     assert session_name is not None
     TEST_SESSION_NAME = session_name
 
     test_name = "testingdis_sessname"
     session.rename_session(test_name)
-    session_name = session.get("session_name")
+    session_name = session.session_name
     assert session_name is not None
     assert session_name == test_name
     session.rename_session(TEST_SESSION_NAME)
-    session_name = session.get("session_name")
+    session_name = session.session_name
     assert session_name is not None
     assert session_name == TEST_SESSION_NAME
 
@@ -109,7 +110,7 @@ def test_new_session(server: Server) -> None:
     new_session = server.new_session(session_name=new_session_name, detach=True)
 
     assert isinstance(new_session, Session)
-    assert new_session.get("session_name") == new_session_name
+    assert new_session.session_name == new_session_name
 
 
 def test_show_options(session: Session) -> None:
@@ -251,9 +252,63 @@ def test_periods_raise_badsessionname(
 
 
 def test_cmd_inserts_sesion_id(session: Session) -> None:
-    current_session_id = session.id
+    current_session_id = session.session_id
     last_arg = "last-arg"
     cmd = session.cmd("not-a-command", last_arg)
     assert "-t" in cmd.cmd
     assert current_session_id in cmd.cmd
     assert cmd.cmd[-1] == last_arg
+
+
+@pytest.mark.skipif(
+    has_lt_version("3.0"),
+    reason="needs -e flag for new-window which was introduced in 3.0",
+)
+@pytest.mark.parametrize(
+    "environment",
+    [
+        {"ENV_VAR": "window"},
+        {"ENV_VAR_1": "window_1", "ENV_VAR_2": "window_2"},
+    ],
+)
+def test_new_window_with_environment(
+    session: Session,
+    environment: t.Dict[str, str],
+) -> None:
+    env = shutil.which("env")
+    assert env is not None, "Cannot find usable `env` in PATH."
+
+    window = session.new_window(
+        attach=True,
+        window_name="window_with_environment",
+        window_shell=f"{env} PS1='$ ' sh",
+        environment=environment,
+    )
+    pane = window.attached_pane
+    assert pane is not None
+    for k, v in environment.items():
+        pane.send_keys(f"echo ${k}")
+        assert pane.capture_pane()[-2] == v
+
+
+@pytest.mark.skipif(
+    has_gte_version("3.0"),
+    reason="3.0 has the -e flag on new-window",
+)
+def test_new_window_with_environment_logs_warning_for_old_tmux(
+    session: Session,
+    caplog: pytest.LogCaptureFixture,
+) -> None:
+    env = shutil.which("env")
+    assert env is not None, "Cannot find usable `env` in PATH."
+
+    session.new_window(
+        attach=True,
+        window_name="window_with_environment",
+        window_shell=f"{env} PS1='$ ' sh",
+        environment={"ENV_VAR": "window"},
+    )
+
+    assert any(
+        "Cannot set up environment" in record.msg for record in caplog.records
+    ), "Warning missing"
